# qtMUD

[![Join the chat at https://gitter.im/fyreside/Lobby](https://badges.gitter.im/fyreside/Lobby.svg)](https://gitter.im/fyreside/Lobby?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

[![PyPI version](https://badge.fury.io/py/fyreside.svg)](https://badge.fury.io/py/fyreside)
[![Documentation Status](https://readthedocs.org/projects/fyreside/badge/?version=latest)](http://fyreside.readthedocs.io/en/latest/?badge=latest)

[![Build Status](https://travis-ci.org/emsenn/fyreside.svg?branch=master)](https://travis-ci.org/emsenn/fyreside)

[![Requirements Status](https://requires.io/github/emsenn/fyreside/requirements.svg?branch=master)](https://requires.io/github/emsenn/fyreside/requirements/?branch=master)
------

description

link to full documentation

## Usage

Grabbing from git, running, connecting as client
